@@ -14,7 +14,7 @@ exact syntax.
 
 """
 
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# __COPYRIGHT__
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -34,9 +34,7 @@ exact syntax.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-from __future__ import print_function
-
-__revision__ = "/src/script/src/engine/SCons/Tool/rpmutils.py none 2019-12-17 02:06:27 none"
+__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
 
 import platform
@@ -439,7 +437,7 @@ arch_canon = {
 
 # End of rpmrc dictionaries (Marker, don't change or remove!)
 
-def defaultMachine(use_rpm_default=True):
+def defaultMachine(use_rpm_default: bool=True):
     """ Return the canonicalized machine name. """
 
     if use_rpm_default:
@@ -473,7 +471,7 @@ def defaultNames():
     """ Return the canonicalized machine and system name. """
     return defaultMachine(), defaultSystem()
 
-def updateRpmDicts(rpmrc, pyfile):
+def updateRpmDicts(rpmrc, pyfile) -> None:
     """ Read the given rpmrc file with RPM definitions and update the
         info dictionaries in the file pyfile with it.
         The arguments will usually be 'rpmrc.in' from a recent RPM source
@@ -482,10 +480,10 @@ def updateRpmDicts(rpmrc, pyfile):
     """
     try:
         # Read old rpmutils.py file
-        with open(pyfile,"r") as f:
+        with open(pyfile) as f:
             oldpy = f.readlines()
         # Read current rpmrc.in file
-        with open(rpmrc,"r") as f:
+        with open(rpmrc) as f:
             rpm = f.readlines()
         # Parse for data
         data = {}
@@ -533,10 +531,10 @@ def updateRpmDicts(rpmrc, pyfile):
     except:
         pass
 
-def usage():
+def usage() -> None:
     print("rpmutils.py rpmrc.in rpmutils.py")
 
-def main():
+def main() -> None:
     import sys
 
     if len(sys.argv) < 3:
